@@ -1,11 +1,24 @@
+import os
 import unittest
 from weighting_platform.functions import general_functions
-from weighting_platform.tests.test_objects import test_sql_shell
+from wsqluse.wsqluse import Wsqluse
+
+test_sql_shell = Wsqluse('wdb', 'watchman', 'hect0r1337', '192.168.100.118')
+
 from qdk.main import QDK
+from wserver_qdk.main import WServerQDK
+
+wserverqdk_test = WServerQDK('192.168.100.118', 8888)
+
 from time import sleep
 
 
 class GfTest(unittest.TestCase):
+    def __init__(self, *args, **kwargs):
+        super(GfTest, self).__init__(*args, **kwargs)
+        self.wserver_qdk = wserverqdk_test
+        self.wserver_qdk.make_connection()
+
     def test_get_percent(self):
         first = 1000
         second = 500
@@ -31,14 +44,13 @@ class GfTest(unittest.TestCase):
         response = general_functions.get_mac_ar()
         print(response)
 
-    def test_send_mac_ar(self):
+    def test_self_destroy_func(self):
         qdk = QDK('192.168.100.118', 8888)
         qdk.make_connection()
-        qdk.subscribe()
-        send = general_functions.send_mac_ar('12:12:12')
-        print(send)
-        get_answer = qdk.get_data()
-        print(get_answer)
+        #qdk.subscribe()
+        general_functions.self_destroy_func(self.wserver_qdk)
+        qdk.sock.close()
+
 
 
 if __name__ == '__main__':
